@@ -213,18 +213,27 @@ fr_command_iso_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_iso_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
-	if (is_program_in_path ("isoinfo"))
+	if (is_program_available ("isoinfo", check_command))
 		capabilities |= FR_COMMAND_CAN_READ;
 
 	return capabilities;
 }
 
 
+static const char *
+fr_command_iso_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	return "genisoimage";
+}
+
+
 static void
 fr_command_iso_class_init (FrCommandIsoClass *class)
 {
@@ -240,6 +249,7 @@ fr_command_iso_class_init (FrCommandIsoClass *class)
 	afc->extract          = fr_command_iso_extract;
 	afc->get_mime_types   = fr_command_iso_get_mime_types;
 	afc->get_capabilities = fr_command_iso_get_capabilities;
+	afc->get_packages     = fr_command_iso_get_packages;
 }
 
 
