@@ -183,7 +183,7 @@ static void
 list__begin (gpointer data)
 {
 	FrCommandUnstuff *comm = data;
-	
+
 	comm->fdata = NULL;
 }
 
@@ -202,7 +202,7 @@ fr_command_unstuff_list (FrCommand *comm)
 	fr_process_add_arg (comm->process, "--trace");
 
 	/* Actually unpack everything in a temporary directory */
-	path = get_temp_work_dir ();
+	path = get_temp_work_dir (NULL);
 	path_dots = unstuff_is_shit_with_filenames (path);
 	g_free (path);
 
@@ -268,9 +268,11 @@ static void
 fr_command_unstuff_handle_error (FrCommand   *comm,
 				 FrProcError *error)
 {
-	if ((error->type == FR_PROC_ERROR_COMMAND_ERROR)
+	if ((error->type != FR_PROC_ERROR_NONE)
 	    && (error->status <= 1))
+	{
 		error->type = FR_PROC_ERROR_NONE;
+	}
 }
 
 
@@ -286,18 +288,27 @@ fr_command_unstuff_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_unstuff_get_capabilities (FrCommand  *comm,
-			             const char *mime_type)
+			             const char *mime_type,
+				     gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
-	if (is_program_in_path ("unstuff"))
+	if (is_program_available ("unstuff", check_command))
 		capabilities |= FR_COMMAND_CAN_READ;
 
 	return capabilities;
 }
 
 
+static const char *
+fr_command_unstaff_get_packages (FrCommand  *comm,
+			         const char *mime_type)
+{
+	return "unstaff";
+}
+
+
 static void
 fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 {
@@ -316,6 +327,7 @@ fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 	afc->handle_error     = fr_command_unstuff_handle_error;
 	afc->get_mime_types   = fr_command_unstuff_get_mime_types;
 	afc->get_capabilities = fr_command_unstuff_get_capabilities;
+	afc->get_packages     = fr_command_unstaff_get_packages;
 }
 
 
