@@ -164,8 +164,6 @@ create_button (const char *stock_id,
 	gboolean      text_is_stock;
 	GtkStockItem  stock_item;
 
-	button = gtk_button_new ();
-
 	if (gtk_stock_lookup (text, &stock_item)) {
 		label_text = stock_item.label;
 		text_is_stock = TRUE;
@@ -178,19 +176,12 @@ create_button (const char *stock_id,
 		image = gtk_image_new_from_stock (text, GTK_ICON_SIZE_BUTTON);
 	else
 		image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
-	label = gtk_label_new_with_mnemonic (label_text);
-	hbox = gtk_hbox_new (FALSE, 2);
-	align = gtk_alignment_new (0.5, 0.5, 0.0, 0.0);
+	button = gtk_button_new_with_mnemonic (label_text);
+	gtk_button_set_image (GTK_BUTTON (button), image);
 
 	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-	gtk_label_set_mnemonic_widget (GTK_LABEL (label), GTK_WIDGET (button));
 
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
-	gtk_container_add (GTK_CONTAINER (button), align);
-	gtk_container_add (GTK_CONTAINER (align), hbox);
-
-	gtk_widget_show_all (button);
+	gtk_widget_show (button);
 
 	return button;
 }
@@ -437,7 +428,8 @@ _gtk_error_dialog_new (GtkWindow        *parent,
 		/* Expander */
 
 		expander = gtk_expander_new_with_mnemonic (_("Command _Line Output"));
-
+		gtk_expander_set_expanded (GTK_EXPANDER (expander), secondary_text == NULL);
+		
 		/* Add text */
 
 		scrolled = gtk_scrolled_window_new (NULL, NULL);
@@ -752,16 +744,7 @@ show_uri (GdkScreen   *screen,
 {
 	gboolean result;
 
-#ifndef GTK_2_13
-	GAppLaunchContext *app_context;
-
-	app_context = g_app_launch_context_new ();
-	result = g_app_info_launch_default_for_uri (uri, G_APP_LAUNCH_CONTEXT (app_context), error);
-
-	g_object_unref (app_context);
-#else
 	result = gtk_show_uri (screen, uri, timestamp, error);
-#endif
 
 	return result;
 }
